math library that symbolically solve algebra
expressions are immutable and always sorted

# to do:
parse in codegen. parse strings into expressions. useful in TUI.
make a seperate repo that does TUI
solve quadratic
calculus
tensor class. cpu arithmitic operations
linear algebra basics
cuda codegen
